# PySInfo

PySInfo: A python command line tool that displays information about the current system, including hardware and critical software.

version 1.0

## Installation

### Run from source

```Bash
git clone https://github.com/EasyCam/Pysinfo.git
cd Pysinfo
python -m pip install -r requirements.txt
python -m pysinfo
```

### Install from PyPI

```Bash
pip install pysinfo
python -m pysinfo
```

### Example

```Bash

╒════════════════════════════════════════════════════════════════╕
│     PySinfo: A Python Tool to Get System Infomation            │
╘════════════════════════════════════════════════════════════════╛

                                ..,    OS: Windows 10.0.26100
                    ....,,:;+ccllll    Host: MSI
      ...,,+:;  cllllllllllllllllll    Kernel: 11
,cclllllllllll  lllllllllllllllllll    Uptime: 0 days, 22 hours, 50 minutes
llllllllllllll  lllllllllllllllllll    Shell: cmd.exe
llllllllllllll  lllllllllllllllllll    Terminal: 92x49
llllllllllllll  lllllllllllllllllll
llllllllllllll  lllllllllllllllllll    Hardware:
llllllllllllll  lllllllllllllllllll    CPU Model: AMD Ryzen 9 7945HX with Radeon Graphics
                                       CPU Architecture: AMD64
llllllllllllll  lllllllllllllllllll    CPU Current Freq: 2501.0
llllllllllllll  lllllllllllllllllll    CPU Cores: 16 (Physical), 32 (Logical)
llllllllllllll  lllllllllllllllllll    CPU Usage: 6.3%
llllllllllllll  lllllllllllllllllll    GPU: NVIDIA GeForce RTX 4060 Laptop GPU (8.00 GB)
llllllllllllll  lllllllllllllllllll    Memory: 28.94 GB / 95.18 GB (30.4%)
`'ccllllllllll  lllllllllllllllllll    Memory Slots: 2 (48 GB, 48 GB)
       `' \*::  :ccllllllllllllllll    Memory Speed: 5200 MHz
                       ````''*::cll    Disk: 3.50 TB / 3.64 TB (96.3%)
                                 ``
                                       Network:
                                       IP Address: 192.168.0.2

                                       Development Environment:
                                       Python: 3.12.2 (CPython)
                                       Python Path: C:\Miniconda3\python.exe

                                       Graphics API Support:
                                       CUDA: 12.6.85
                                       OpenCL: Platform Version:                            OpenCL 3.0 CUDA 12.8.51
                                       Vulkan: 1.4.303

██████████████████████████████████████████
```
